@@ -29,13 +29,14 @@ class ApiResponseException(Exception):
     """Class to wrap a response exception from an API
 
     Attributes:
-        status_code (ResponseCode): The status code for this exception
+        status_code (Union[ResponseCode, int]): The status code for this response. Can use builtin ResponseCode Enum
+             or a custom integer
         message (str): The message for this exception
     """
-    status_code: ResponseCode
+    status_code: Union[ResponseCode, int]
     message: str
 
-    def __init__(self, status_code: ResponseCode, message: str):
+    def __init__(self, status_code: Union[ResponseCode, int], message: str):
         """Inits APIResponseException with status_code and message"""
         self.status_code = status_code
         self.message = message
@@ -116,15 +117,20 @@ class ApiResponseFactory(ABC):
         """
         return type(self.body) is ApiErrorResponseBody
 
-    def set_error(self, error_code: ResponseCode, message: str):
+    def set_error(self, error_code: Union[ResponseCode, int], message: str):
         """Set the error code and message for this response
 
         Args:
-            error_code (ResponseCode): The error code for this response
+            error_code (Union[ResponseCode, int]): The error code for this response. Can use builtin ResponseCode Enum
+                or a custom integer
             message (str): The message for this response
         """
         self.body = ApiErrorResponseBody(message)
-        self.status_code = error_code.value
+
+        if type(error_code) is ResponseCode:
+            self.status_code = error_code.value
+        elif type(error_code) is int:
+            self.status_code = error_code
 
     def set_exception(self, error: Union[Exception, ApiResponseException]):
         """Set the exception for this response
